WrapContext extension
- on
Methods
-
wrap(
Widget builder(BuildContext context, Widget child)) → Widget -
Available on Widget, provided by the WrapContext extension
Same as wrapping current widget with a Builder, which keeps chain style.
Available on Widget, provided by the WrapContext extension
Same as wrapping current widget with a Builder, which keeps chain style.